list

Function list 

pub fn list(
    source: Option<Utf8PathBuf>,
    all: bool,
    icons_override: Option<IconsMode>,
    no_color: bool,
) -> Result<()>
Show the resolved src→dst mappings for the current source repo.

By default only entries whose when matches the current host are shown (active). With --all, inactive entries are included with a dim row and the when condition that excluded them.