is_clean

Function is_clean 

pub fn is_clean(repo: &Utf8Path) -> Result<bool>
Returns true when the working tree at repo has no uncommitted changes and no untracked files (i.e. git status --porcelain is empty). Err(Error::Git(_)) if git isn’t on $PATH or repo isn’t a repository.