.yuilink marker file detection.
Under marker strategy, a directory containing the configured marker file
(default .yuilink) is the link point — yui creates a single
junction/symlink for that directory and stops recursing.
.yuilink marker file detection.
Under marker strategy, a directory containing the configured marker file
(default .yuilink) is the link point — yui creates a single
junction/symlink for that directory and stops recursing.